@@ -7,7 +7,7 @@ if (FALSE) {
   inc    <- "FALSE"
   log    <-  c("FALSE")
   
-  M <- 50
+  M <- 10
   
   alpha_vec     <- rep(0,M)
   s_vec         <- rep(0,M)
@@ -17,14 +17,20 @@ if (FALSE) {
   
       net  <- GenerateNet(N = 1000, m = 50,prob_m = prob_m, num_seed = 100, multiple_node = 100,
                           increase = inc, log = log, 
-                          mode = 1, shape = 1, rate = 1,alpha = 0.25)
+                          mode = 1, shape = 1000, rate = 1000,alpha = 1)
   
       net_stats <- GetStatistics(net$graph,deg_threshold = 0, 
                                  net_type = "directed",
                                  Binning = TRUE, G = 50) 
   
-      print(system.time(result <- JointEstimate(raw_net = net$graph, net_stat = net_stats, print.out = TRUE,
-                                              cv_deg_thresh = c(1,10))))
+      print(system.time(result <- JointEstimate(raw_net = net$graph, 
+                                                p = 0.75, 
+                                                weight_f = -0.5,
+                                                mode_reg_A = 1,
+                                                stop.cond = 10^-9,
+                                                net_stat = net_stats, 
+                                                print.out = TRUE,
+                                                cv_deg_thresh = c(1,5,10))))
       
       alpha_vec[i]     <- result$estimate_result$alpha
       s_vec[i]         <- result$estimate_result$shape
@@ -32,6 +38,7 @@ if (FALSE) {
       r_optimal[i]     <- result$cv_result$r_optimal
   }
   print(alpha_vec)  
+  mean(alpha_vec)
   print(s_vec)
   mean(s_vec)
 }
\ No newline at end of file
