@@ -14,7 +14,8 @@ net_stats <- GetStatistics(net$graph,deg_threshold = 1,
                            net_type = "directed",
                            Binning = TRUE, G = 10) 
 
-result <- PAFit(net_stats,mode_f = "Log_linear",
-                auto_stop =  TRUE, s = 100,
-                stop_cond = 10^-8,normalized_f = FALSE, debug = TRUE)
+result <- PAFit(net_stats,mode_f = "Log_linear",s = 100, debug = TRUE)
+
+result_2 <- PAFit(net_stats, true_f = result$f, s = 100, debug = TRUE)
+
 print(result)
